#
# spec file for package perl-SVG
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name SVG
Name:           perl-SVG
Version:        2.87
Release:        1.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl extension for generating Scalable Vector Graphics (SVG) documents
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MANWAR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.94
BuildRequires:  perl(parent)
Requires:       perl(parent)
%{perl_requires}

%description
SVG is a 100% Perl module which generates a nested data structure
containing the DOM representation of an SVG (Scalable Vector Graphics)
image. Using SVG, you can generate SVG objects, embed other SVG instances
into it, access the DOM object, create and access javascript, and generate
SMIL animation content.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README
%license LICENSE

%changelog
* Fri May 20 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.87
  see /usr/share/doc/packages/perl-SVG/Changes
  2.87  2022.05.19 MANWAR
  - Indent doc for text PR #15, thanks @benkasminbullock.
  - Remove dead links to domain-squatted site PR #16, thanks @benkasminbullock.
  - Perldity code base (still 2 not happy).
* Fri Apr 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.86
  see /usr/share/doc/packages/perl-SVG/Changes
  2.86  2021.04.22 MANWAR
  - Replace last use of "vars" with "our", thanks @JRaspass.
* Fri Jul  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.85
  see /usr/share/doc/packages/perl-SVG/Changes
  2.85  2020.07.02 MANWAR
  - Minor documentation fix, thanks @polettix.
  - Fixed broken author test (xt/author).
* Tue Feb 20 2018 coolo@suse.com
- updated to 2.84
  see /usr/share/doc/packages/perl-SVG/Changes
  2.84  2018.02.19 MANWAR
  - Removed '+x' bits from the script "xt/author/pod-syntax.t".
* Tue Feb 13 2018 coolo@suse.com
- updated to 2.83
  see /usr/share/doc/packages/perl-SVG/Changes
  2.83  2018.02.12 MANWAR
  - Merged PR #11 (Test Reports), thanks @genio.
* Tue Jan 23 2018 coolo@suse.com
- updated to 2.82
  see /usr/share/doc/packages/perl-SVG/Changes
  2.82  2017.12.18 MANWAR
  - Fixed subquery (txn-1762542) of the issue RT #123896.
* Mon Dec 18 2017 coolo@suse.com
- updated to 2.81
  see /usr/share/doc/packages/perl-SVG/Changes
  2.81  2017.12.17 MANWAR
  - Fixed issue RT #123896 (trailing space in credit comment).
* Fri Dec  8 2017 coolo@suse.com
- updated to 2.80
  see /usr/share/doc/packages/perl-SVG/Changes
  2.80  2017.11.30 MANWAR
  - Added one more test author only as suggested by @DAVE. (RT #123705)
* Fri Dec  1 2017 coolo@suse.com
- updated to 2.79
  see /usr/share/doc/packages/perl-SVG/Changes
  2.79  2017.11.30 MANWAR
  - Addressed RT #123705, making test t/96-perl-critic.t and t/99_test_pod_coverage.t author only.
* Sat Jul  8 2017 coolo@suse.com
- updated to 2.78
  see /usr/share/doc/packages/perl-SVG/Changes
  2.78  2017.07.07 MANWAR
  - Merged PR #10 (fix entity escaping), thanks @haarg. This also resolved RT #121612.
* Fri May 19 2017 coolo@suse.com
- updated to 2.77
  see /usr/share/doc/packages/perl-SVG/Changes
  2.77  2017.05.18 MANWAR
  - Proposed fix to the following test failure:
    http://www.cpantesters.org/cpan/report/ddc7eefc-3429-11e7-8430-9cfb106f656a
* Tue May 16 2017 coolo@suse.com
- updated to 2.76
  see /usr/share/doc/packages/perl-SVG/Changes
  2.76  2017.05.08 MANWAR
  - Added AUTHOR ONLY test scripts (meta-json.t and meta-yml.t).
  2.75  2017.05.07 MANWAR
  - Tidied up unit test scripts and removed '+x' attributes.
  - Tidied up SEE ALSO section in SVG::XML package pod.
* Sat May  6 2017 coolo@suse.com
- updated to 2.74
  see /usr/share/doc/packages/perl-SVG/Changes
  2.74  2017.05.04 MANWAR
  - Added key 'provides' to the Makefile.PL script as recommended by CPANTS.
  2.73  2017.05.03 MANWAR
  - Merged PR #8, thanks @CSSON. Modified slightly to keep tidyall happy.
  - Correct some spelling errors that were detected by codespell.
  - Don't insert whitespace between tag name and closing bracked when a tag has no attributes
* Wed May  3 2017 coolo@suse.com
- updated to 2.72
  see /usr/share/doc/packages/perl-SVG/Changes
  2.72  2017.05.02 MANWAR
  - Added test script t/00-load.t
  - Fixed typo in the pod document.
  2.71  2017.05.01 MANWAR
  - Fixed issue RT #57000 with regard to be explici about SVG instance.
  2.70  2017.04.27 MANWAR
  - Added MIN_PERL_VERSION to the Makefile.PL script as suggested by CPANTS.
* Tue Apr 25 2017 coolo@suse.com
- updated to 2.69
  see /usr/share/doc/packages/perl-SVG/Changes
  2.69  2017.04.20 MANWAR
  - Fixed issue RT #118091, skip test if Perl::Tidy is missing.
  2.68  2017.04.19 MANWAR
  - Fixed issue RT #109521, adding min ver of Test::More v0.94.
* Wed Apr 19 2017 coolo@suse.com
- updated to 2.67
  see /usr/share/doc/packages/perl-SVG/Changes
  2.67  2017.04.18 MANWAR
  - Fixed the issue with regard to github respository info in the Makefile.PL script, thanks @KENTNL.
  2.66  2017.04.17 MANWAR
  - Addressed issue RT #121197 (incorrect meta spec), thanks @KENTNL.
  - Added 'clean' and 'dist' keys to the Makefile.PL script.
  - Tidied up .gitignore file.
  - Added MANIFEST file, no need to generate every time.
* Mon Apr 17 2017 coolo@suse.com
- updated to 2.65
  see /usr/share/doc/packages/perl-SVG/Changes
* Sun Jun  7 2015 coolo@suse.com
- updated to 2.64
  see /usr/share/doc/packages/perl-SVG/Changes
  2.64 2015.06.02
  - RT #103938 SVG::DOM insertSiblingAfter calls nonexistent 'parent' method (Marius Gavrilescu)
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.63
  see /usr/share/doc/packages/perl-SVG/Changes
  2.63 2015.03.06
  - Move SVG results from POD to external files.
  2.62 2015.03.06
  - Remove more duplicate pod.
  - Encoding of the pod RT #89414
  2.61 2015.03.03
  - Eliminate a bunch of duplicate documentation.
  - Skip tidy testing if module is not available (RT #102484)
  - POD formatting.
  2.60 2015.03.03
  - Convert source files to utf8
  - Add more tests
  - css styles are now sorted to make it easeier to test
  - Run Perltidy on the code
* Tue Jun  4 2013 coolo@suse.com
- updated to 2.59
  - Experiment to show images on MetaCPAN
  - Move all the content of SVG::Manual to SVG
  - Add an image to the pod generated by and example.
  - Rename SVG::Manual from .pm to .pod.
  - Stop violating the Subroutines::ProhibitExplicitReturnUndef policy,
    eliminate 'return undef' and return wantarray?():undef; from the code.
  - Update the dates in the Changes file.
  - Remove the function prototypes that don't work on methods anyway.
    Stop violating the Subroutines::ProhibitSubroutinePrototypes policy.
  - missing test file removed from MANIFEST (RT #78856)
  - move POD testing to xt/
  - Some example cleanup - Shlomi Fish
  - removing prototype - Shlomi Fish
  - POD fixes - David Paleino
* Mon May 28 2012 coolo@suse.com
- updated to 2.51
  - Maintenance by Gabor Szabo
  - Some documentation fixes.
  - Modernizing test suite.
  - Link to new public repository.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Aug  4 2010 chris@computersalat.de
- initial package 2.50
  * created by cpanspec 1.78
